/**
 * This file has no copyright assigned and is placed in the Public Domain.
 * This file is part of the mingw-w64 runtime package.
 * No warranty is given; refer to the file DISCLAIMER.PD within this package.
 */

#ifndef _L2CMN_H
#define _L2CMN_H

#define L2_NOTIFICATION_SOURCE_NONE             0
#define L2_NOTIFICATION_SOURCE_DOT3_AUTO_CONFIG 0x00000001
#define L2_NOTIFICATION_SOURCE_SECURITY         0x00000002
#define L2_NOTIFICATION_SOURCE_ONEX             0x00000004
#define L2_NOTIFICATION_SOURCE_WLAN_ACM         0x00000008
#define L2_NOTIFICATION_SOURCE_WLAN_MSM         0x00000010
#define L2_NOTIFICATION_SOURCE_WLAN_SECURITY    0x00000020
#define L2_NOTIFICATION_SOURCE_WLAN_IHV         0x00000040
#define L2_NOTIFICATION_SOURCE_WLAN_HNWK        0x00000080

#endif /* _L2CMN_H */
